@@ -12,31 +12,37 @@ from __future__ import (
 import abc
 import collections
 import os
-import typing as t
 from pathlib import (
     Path,
 )
+from typing import (
+    Any,
+    NoReturn,
+    Union,
+)
 
 import yaml
 
 from ..exceptions import (
-    MinosConfigDefaultAlreadySetException,
     MinosConfigException,
 )
 
 BROKER = collections.namedtuple("Broker", "host port")
 QUEUE = collections.namedtuple("Queue", "database user password host port records retry")
 ENDPOINT = collections.namedtuple("Endpoint", "name route method controller action")
-SERVICE = collections.namedtuple("Service", "name")
+SERVICE = collections.namedtuple("Service", "name injections services")
 CONTROLLER = collections.namedtuple("Controller", "name controller action")
 STORAGE = collections.namedtuple("Storage", "path")
 
 EVENTS = collections.namedtuple("Events", "broker items queue")
 COMMANDS = collections.namedtuple("Commands", "broker items queue")
-SAGA = collections.namedtuple("Saga", "items queue storage")
+SAGA = collections.namedtuple("Saga", "items queue storage broker")
 REST = collections.namedtuple("Rest", "broker endpoints")
 REPOSITORY = collections.namedtuple("Repository", "database user password host port")
 SNAPSHOT = collections.namedtuple("Snapshot", "database user password host port")
+DISCOVERY_ENDPOINT = collections.namedtuple("DiscoveryEndpoint", "path method")
+DISCOVERY_ENDPOINTS = collections.namedtuple("DiscoveryEndpoints", "subscribe unsubscribe discover")
+DISCOVERY = collections.namedtuple("Discovery", "host port endpoints")
 
 _ENVIRONMENT_MAPPER = {
     "commands.queue.host": "MINOS_COMMANDS_QUEUE_HOST",
@@ -46,6 +52,8 @@ _ENVIRONMENT_MAPPER = {
     "commands.queue.password": "MINOS_COMMANDS_QUEUE_PASSWORD",
     "commands.broker": "MINOS_COMMANDS_BROKER",
     "commands.port": "MINOS_COMMANDS_PORT",
+    "saga.broker": "MINOS_SAGA_BROKER",
+    "saga.port": "MINOS_SAGA_PORT",
     "saga.queue.host": "MINOS_SAGA_QUEUE_HOST",
     "saga.queue.port": "MINOS_SAGA_QUEUE_PORT",
     "saga.queue.database": "MINOS_SAGA_QUEUE_DATABASE",
@@ -68,6 +76,14 @@ _ENVIRONMENT_MAPPER = {
     "snapshot.database": "MINOS_SNAPSHOT_DATABASE",
     "snapshot.user": "MINOS_SNAPSHOT_USER",
     "snapshot.password": "MINOS_SNAPSHOT_PASSWORD",
+    "discovery.host": "MINOS_DISCOVERY_HOST",
+    "discovery.port": "MINOS_DISCOVERY_PORT",
+    "discovery.endpoints.subscribe.path": "MINOS_DISCOVERY_ENDPOINTS_SUBSCRIBE_PATH",
+    "discovery.endpoints.subscribe.method": "MINOS_DISCOVERY_ENDPOINTS_SUBSCRIBE_METHOD",
+    "discovery.endpoints.unsubscribe.path": "MINOS_DISCOVERY_ENDPOINTS_UNSUBSCRIBE_PATH",
+    "discovery.endpoints.unsubscribe.method": "MINOS_DISCOVERY_ENDPOINTS_UNSUBSCRIBE_METHOD",
+    "discovery.endpoints.discover.path": "MINOS_DISCOVERY_ENDPOINTS_DISCOVER_PATH",
+    "discovery.endpoints.discover.method": "MINOS_DISCOVERY_ENDPOINTS_DISCOVER_METHOD",
 }
 
 _PARAMETERIZED_MAPPER = {
@@ -78,6 +94,8 @@ _PARAMETERIZED_MAPPER = {
     "commands.queue.password": "commands_queue_password",
     "commands.broker": "commands_broker",
     "commands.port": "commands_port",
+    "saga.broker": "saga_broker",
+    "saga.port": "saga_port",
     "saga.queue.host": "saga_queue_host",
     "saga.queue.port": "saga_queue_port",
     "saga.queue.database": "saga_queue_database",
@@ -100,17 +118,23 @@ _PARAMETERIZED_MAPPER = {
     "snapshot.database": "snapshot_database",
     "snapshot.user": "snapshot_user",
     "snapshot.password": "snapshot_password",
+    "discovery.host": "minos_discovery_host",
+    "discovery.port": "minos_discovery_port",
+    "discovery.endpoints.subscribe.path": "minos_discovery_endpoints_subscribe_path",
+    "discovery.endpoints.subscribe.method": "minos_discovery_endpoints_subscribe_method",
+    "discovery.endpoints.unsubscribe.path": "minos_discovery_endpoints_unsubscribe_path",
+    "discovery.endpoints.unsubscribe.method": "minos_discovery_endpoints_unsubscribe_method",
+    "discovery.endpoints.discover.path": "minos_discovery_endpoints_discover_path",
+    "discovery.endpoints.discover.method": "minos_discovery_endpoints_discover_method",
 }
 
-_default: t.Optional[MinosConfigAbstract] = None
-
 
 class MinosConfigAbstract(abc.ABC):
     """Minos abstract config class."""
 
     __slots__ = "_services", "_path"
 
-    def __init__(self, path: t.Union[Path, str]):
+    def __init__(self, path: Union[Path, str]):
         if isinstance(path, str):
             path = Path(path)
         self._services = {}
@@ -122,49 +146,23 @@ class MinosConfigAbstract(abc.ABC):
         raise NotImplementedError
 
     @abc.abstractmethod
-    def _get(self, key: str, **kwargs: t.Any):
+    def _get(self, key: str, **kwargs: Any):
         raise NotImplementedError
 
-    def __enter__(self) -> MinosConfigAbstract:
-        self.set_default(self)
-        return self
-
-    def __exit__(self, exc_type, exc_val, exc_tb) -> t.NoReturn:
-        self.unset_default()
-
-    @staticmethod
-    def set_default(value: MinosConfigAbstract) -> t.NoReturn:
-        """Set default config.
-
-        :param value: Default config.
-        :return: This method does not return anything.
-        """
-        if MinosConfigAbstract.get_default() is not None:
-            raise MinosConfigDefaultAlreadySetException("There is already another config set as default.")
-        global _default
-        _default = value
-
-    @classmethod
-    def get_default(cls) -> MinosConfigAbstract:
-        """Get default config.
-
-        :return: A ``MinosConfigAbstract`` instance.
-        """
-        global _default
-        return _default
-
-    @staticmethod
-    def unset_default() -> t.NoReturn:
-        """Unset the default config.
-
-        :return: This method does not return anything.
-        """
-        global _default
-        _default = None
-
 
 class MinosConfig(MinosConfigAbstract):
-    """Minos config class."""
+    """
+    A Minos configuration provides information on the connection points available at that service.
+    It consists of the following parts:
+
+    - Service meta-information (such as name, or version).
+    - REST Service endpoints available.
+    - Repository database connection for event sourcing.
+    - Snapshot database connection.
+    - Events it publishes/consumes from de given Kafka service.
+    - Commands it reacts to from other microservices.
+    - Sagas it takes part on.
+    """
 
     __slots__ = ("_data", "_with_environment", "_parameterized")
 
@@ -173,21 +171,21 @@ class MinosConfig(MinosConfigAbstract):
         self._with_environment = with_environment
         self._parameterized = kwargs
 
-    def _load(self, path: Path) -> t.NoReturn:
+    def _load(self, path: Path) -> NoReturn:
         if not path.exists():
             raise MinosConfigException(f"Check if this path: {path} is correct")
 
         with path.open() as file:
             self._data = yaml.load(file, Loader=yaml.FullLoader)
 
-    def _get(self, key: str, **kwargs: t.Any) -> t.Any:
+    def _get(self, key: str, **kwargs: Any) -> Any:
         if key in _PARAMETERIZED_MAPPER and _PARAMETERIZED_MAPPER[key] in self._parameterized:
             return self._parameterized[_PARAMETERIZED_MAPPER[key]]
 
         if self._with_environment and key in _ENVIRONMENT_MAPPER and _ENVIRONMENT_MAPPER[key] in os.environ:
             return os.environ[_ENVIRONMENT_MAPPER[key]]
 
-        def _fn(k: str, data: dict[str, t.Any]) -> t.Any:
+        def _fn(k: str, data: dict[str, Any]) -> Any:
             current, _, following = k.partition(".")
 
             part = data[current]
@@ -204,7 +202,23 @@ class MinosConfig(MinosConfigAbstract):
 
         :return: A ``SERVICE`` NamedTuple instance.
         """
-        return SERVICE(name=self._get("service.name"))
+        return SERVICE(
+            name=self._get("service.name"), injections=self._service_injections, services=self._service_services
+        )
+
+    @property
+    def _service_injections(self) -> dict[str, str]:
+        try:
+            return self._get("service.injections")
+        except KeyError:
+            return dict()
+
+    @property
+    def _service_services(self) -> list[str]:
+        try:
+            return self._get("service.services")
+        except KeyError:
+            return list()
 
     @property
     def rest(self) -> REST:
@@ -228,7 +242,7 @@ class MinosConfig(MinosConfigAbstract):
         return endpoints
 
     @staticmethod
-    def _rest_endpoints_entry(endpoint: dict[str, t.Any]) -> ENDPOINT:
+    def _rest_endpoints_entry(endpoint: dict[str, Any]) -> ENDPOINT:
         return ENDPOINT(
             name=endpoint["name"],
             route=endpoint["route"],
@@ -271,7 +285,7 @@ class MinosConfig(MinosConfigAbstract):
         return events
 
     @staticmethod
-    def _events_items_entry(event: dict[str, t.Any]) -> CONTROLLER:
+    def _events_items_entry(event: dict[str, Any]) -> CONTROLLER:
         return CONTROLLER(name=event["name"], controller=event["controller"], action=event["action"])
 
     @property
@@ -294,7 +308,8 @@ class MinosConfig(MinosConfigAbstract):
         queue = self._sagas_queue
         sagas = self._saga_items
         storage = self._saga_storage
-        return SAGA(items=sagas, queue=queue, storage=storage)
+        broker = self._saga_broker
+        return SAGA(items=sagas, queue=queue, storage=storage, broker=broker)
 
     @property
     def _commands_broker(self) -> BROKER:
@@ -321,7 +336,7 @@ class MinosConfig(MinosConfigAbstract):
         return commands
 
     @staticmethod
-    def _commands_items_entry(command: dict[str, t.Any]) -> CONTROLLER:
+    def _commands_items_entry(command: dict[str, Any]) -> CONTROLLER:
         return CONTROLLER(name=command["name"], controller=command["controller"], action=command["action"])
 
     @property
@@ -332,6 +347,10 @@ class MinosConfig(MinosConfigAbstract):
         queue = STORAGE(path=path)
         return queue
 
+    @property
+    def _saga_broker(self) -> BROKER:
+        return BROKER(host=self._get("saga.broker"), port=int(self._get("saga.port")))
+
     @property
     def _sagas_queue(self) -> QUEUE:
         queue = QUEUE(
@@ -352,7 +371,7 @@ class MinosConfig(MinosConfigAbstract):
         return sagas
 
     @staticmethod
-    def _sagas_items_entry(saga: dict[str, t.Any]) -> CONTROLLER:
+    def _sagas_items_entry(saga: dict[str, Any]) -> CONTROLLER:
         return CONTROLLER(name=saga["name"], controller=saga["controller"], action=saga["action"])
 
     @property
@@ -382,3 +401,46 @@ class MinosConfig(MinosConfigAbstract):
             host=self._get("snapshot.host"),
             port=int(self._get("snapshot.port")),
         )
+
+    @property
+    def discovery(self) -> DISCOVERY:
+        """Get the sagas config.
+
+        :return: A ``DISCOVERY`` NamedTuple instance.
+        """
+        host = self._get("discovery.host")
+        port = self._get("discovery.port")
+        endpoints = self._discovery_endpoints
+        return DISCOVERY(host=host, port=port, endpoints=endpoints)
+
+    @property
+    def _discovery_endpoints(self) -> DISCOVERY_ENDPOINTS:
+        subscribe = self._discovery_subscribe
+        unsubscribe = self._discovery_unsubscribe
+        discover = self._discovery_discover
+
+        return DISCOVERY_ENDPOINTS(subscribe=subscribe, unsubscribe=unsubscribe, discover=discover)
+
+    @property
+    def _discovery_subscribe(self) -> DISCOVERY_ENDPOINT:
+        endpoint = DISCOVERY_ENDPOINT(
+            path=self._get("discovery.endpoints.subscribe.path"),
+            method=self._get("discovery.endpoints.subscribe.method"),
+        )
+        return endpoint
+
+    @property
+    def _discovery_unsubscribe(self) -> DISCOVERY_ENDPOINT:
+        endpoint = DISCOVERY_ENDPOINT(
+            path=self._get("discovery.endpoints.unsubscribe.path"),
+            method=self._get("discovery.endpoints.unsubscribe.method"),
+        )
+        return endpoint
+
+    @property
+    def _discovery_discover(self) -> DISCOVERY_ENDPOINT:
+        endpoint = DISCOVERY_ENDPOINT(
+            path=self._get("discovery.endpoints.discover.path"),
+            method=self._get("discovery.endpoints.discover.method"),
+        )
+        return endpoint
